@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* for the design docs see bftextview2.h */
@@ -64,6 +63,36 @@ static GdkColor st_cline_color;
 
 /****************************** utility functions ******************************/
 
+static inline gboolean is_symbol(BluefishTextView *btv, gint contextnum, gunichar uc) {
+	if (uc > 127)
+		return FALSE;
+	return (g_array_index(btv->bflang->st->table, Ttablerow, g_array_index(btv->bflang->st->contexts, Tcontext, contextnum).identstate).row[uc] != g_array_index(btv->bflang->st->contexts, Tcontext, contextnum).identstate);
+}
+
+gchar *bf_get_identifier_at_iter(BluefishTextView *btv, GtkTextIter *iter, gint *contextnum) {
+	GQueue *contextstack;
+	GtkTextIter so,eo;
+
+	so=eo=*iter;
+	if (!btv->bflang || !btv->bflang->st) {
+		while (gtk_text_iter_backward_char(&so) && !g_unichar_isspace(gtk_text_iter_get_char(&so))) {};
+		gtk_text_iter_forward_char(&so);
+		while (!g_unichar_isspace(gtk_text_iter_get_char(&eo)) && gtk_text_iter_forward_char(&eo)) {};
+		
+		return gtk_text_buffer_get_text(gtk_text_view_get_buffer(GTK_TEXT_VIEW(btv)), &so,&eo,TRUE);
+	}
+	contextstack = get_contextstack_at_position(btv, iter);
+	if (g_queue_get_length(contextstack)>0)
+		*contextnum = GPOINTER_TO_INT(g_queue_peek_head(contextstack));
+	else
+		*contextnum = 1;
+
+	while (gtk_text_iter_backward_char(&so) && !is_symbol(btv,*contextnum,gtk_text_iter_get_char(&so))) {};
+	gtk_text_iter_forward_char(&so);
+	while (gtk_text_iter_forward_char(&eo) && !is_symbol(btv,*contextnum,gtk_text_iter_get_char(&eo))) {};
+	return gtk_text_buffer_get_text(gtk_text_view_get_buffer(GTK_TEXT_VIEW(btv)), &so,&eo,TRUE); 
+}
+
 gboolean bf_text_iter_line_start_of_text(GtkTextIter *iter, GtkTextIter *realend) {
 	gtk_text_iter_set_line_offset(iter, 0);
 	*realend = *iter;
@@ -438,52 +467,65 @@ static void bftextview2_insert_text_after_lcb(GtkTextBuffer * buffer, GtkTextIte
 	DBG_MARGIN("\n");
 }*/
 
-static inline void paint_margin_expand(BluefishTextView *btv,GdkEventExpose * event,gint w,gint height) {
-/*	gtk_paint_box(GTK_WIDGET(btv)->style, event->window, GTK_STATE_ACTIVE,
-				  GTK_SHADOW_OUT, NULL, GTK_WIDGET(btv), NULL, 21, w + (height / 2 - 4), 9, 9);
-	gtk_paint_hline(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv), NULL,
-					GTK_WIDGET(btv), NULL, 23, 28, w + (height / 2));
-	gtk_paint_vline(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv), NULL,
-					GTK_WIDGET(btv), NULL, w + (height / 2) + 4, w + height, 25);*/
-	gdk_draw_rectangle(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->base_gc[GTK_WIDGET_STATE(btv)], TRUE,btv->margin_pixels_chars+btv->margin_pixels_symbol+1, w + (height / 2) - 4, 8,8);
+static inline void paint_margin_expand(BluefishTextView *btv,cairo_t *cr,gint w,gint height) {
+/*	gdk_draw_rectangle(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->base_gc[GTK_WIDGET_STATE(btv)], TRUE,btv->margin_pixels_chars+btv->margin_pixels_symbol+1, w + (height / 2) - 4, 8,8);
 	gdk_draw_rectangle(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)], FALSE,btv->margin_pixels_chars+btv->margin_pixels_symbol+1, w + (height / 2) - 4, 8,8);
 	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+5,w + (height / 2) + 5,btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w + height);
-	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+3,w + (height / 2), btv->margin_pixels_chars+btv->margin_pixels_symbol+7,w + (height / 2));
+	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+3,w + (height / 2), btv->margin_pixels_chars+btv->margin_pixels_symbol+7,w + (height / 2));*/
+	gdk_cairo_set_source_color(cr, &gtk_widget_get_style(GTK_WIDGET(btv))->base[GTK_WIDGET_STATE(btv)]);
+	cairo_rectangle(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+2, w + (height / 2) - 3, 7,7);
+	cairo_fill(cr);
+	gdk_cairo_set_source_color(cr, &gtk_widget_get_style(GTK_WIDGET(btv))->fg[GTK_WIDGET_STATE(btv)]);
+	cairo_rectangle(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+1.5, w+(height/2)-3.5, 8,8);
+	cairo_move_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w+(height/2)+5);
+	cairo_line_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w+height+0.5);
+	cairo_move_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+3, w+(height/2)+0.5);
+	cairo_line_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+8, w+(height/2)+0.5);
+	cairo_stroke(cr);
 }
 
-static inline void paint_margin_collapse(BluefishTextView *btv,GdkEventExpose * event,gint w,gint height) {
-/*	gtk_paint_box(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv),
-				  GTK_SHADOW_OUT, NULL, GTK_WIDGET(btv), NULL, 21, w + (height / 2 - 4), 9, 9);
-	gtk_paint_hline(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv), NULL,
-					GTK_WIDGET(btv), NULL, 23, 28, w + (height / 2));
-	gtk_paint_vline(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv), NULL,
-					GTK_WIDGET(btv), NULL, w + (height / 2) -2, w + (height / 2) +2, 25);
-	gtk_paint_vline(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv), NULL,
-					GTK_WIDGET(btv), NULL, w + (height / 2) + 4, w + height, 25);*/
-	gdk_draw_rectangle(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->base_gc[GTK_WIDGET_STATE(btv)], TRUE,btv->margin_pixels_chars+btv->margin_pixels_symbol+1, w + (height / 2) - 4, 8,8);
+static inline void paint_margin_collapse(BluefishTextView *btv,cairo_t *cr,gint w,gint height) {
+/*	gdk_draw_rectangle(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->base_gc[GTK_WIDGET_STATE(btv)], TRUE,btv->margin_pixels_chars+btv->margin_pixels_symbol+1, w + (height / 2) - 4, 8,8);
 	gdk_draw_rectangle(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)], FALSE,btv->margin_pixels_chars+btv->margin_pixels_symbol+1, w + (height / 2) - 4, 8,8);
 	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+5,w + (height / 2)-2,btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w + (height / 2)+2);
 	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+5,w + (height / 2) + 5,btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w + height);
-	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+3,w + (height / 2), btv->margin_pixels_chars+btv->margin_pixels_symbol+7,w + (height / 2));
+	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+3,w + (height / 2), btv->margin_pixels_chars+btv->margin_pixels_symbol+7,w + (height / 2));*/
+	gdk_cairo_set_source_color(cr, &gtk_widget_get_style(GTK_WIDGET(btv))->base[GTK_WIDGET_STATE(btv)]);
+	cairo_rectangle(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+2, w + (height / 2) - 3, 7,7);
+	cairo_fill(cr);
+	gdk_cairo_set_source_color(cr, &gtk_widget_get_style(GTK_WIDGET(btv))->fg[GTK_WIDGET_STATE(btv)]);
+	cairo_rectangle(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+1.5, w + (height / 2) - 3.5, 8,8);
+	cairo_move_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w + (height / 2)-2);
+	cairo_line_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w + (height / 2)+3);
+	cairo_move_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w + (height/2) + 5);
+	cairo_line_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w+height+0.5);
+	cairo_move_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+3, w + (height / 2)+0.5);
+	cairo_line_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+8, w + (height / 2)+0.5);
+	cairo_stroke(cr);
 }
 
-static inline void paint_margin_blockend(BluefishTextView *btv,GdkEventExpose * event,gint w,gint height) {
-	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w, btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w + (height/2));
-	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w+(height/2), btv->margin_pixels_chars+btv->margin_pixels_symbol+8, w + (height/2));
-/*	gtk_paint_vline(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv), NULL,
-					GTK_WIDGET(btv), NULL, w, w + (height / 2), 25);
-	gtk_paint_hline(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv), NULL,
-					GTK_WIDGET(btv), NULL, 25, 29, w + (height / 2));*/
+static inline void paint_margin_blockend(BluefishTextView *btv,cairo_t *cr,gint w,gint height) {
+	/*gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w, btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w + (height/2));
+	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w+(height/2), btv->margin_pixels_chars+btv->margin_pixels_symbol+8, w + (height/2));*/
+	cairo_move_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w);
+	cairo_line_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w + (height/2)+0.5);
+	cairo_move_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w+(height/2)+0.5);
+	cairo_line_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+8.5, w+(height/2)+0.5);
+	cairo_stroke(cr);
 }
 
-static inline void paint_margin_line(BluefishTextView *btv,GdkEventExpose * event,gint w,gint height) {
-	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w, btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w + height);
-	/*gtk_paint_vline(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv), NULL,
-					GTK_WIDGET(btv), NULL, w, w + height, 25);*/
+static inline void paint_margin_line(BluefishTextView *btv,cairo_t *cr,gint w,gint height) {
+/*	gdk_draw_line(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)],btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w, btv->margin_pixels_chars+btv->margin_pixels_symbol+5, w + height);*/
+	cairo_move_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w);
+	cairo_line_to(cr, btv->margin_pixels_chars+btv->margin_pixels_symbol+5.5, w + height);
+	cairo_stroke(cr);
 }
 
-static inline void paint_margin_symbol(BluefishTextView *btv,GdkEventExpose * event,gint w,gint height) {
-	gdk_draw_rectangle(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)], TRUE,btv->margin_pixels_chars+2, w + (height / 2) - 4, 8,8);
+static inline void paint_margin_symbol(BluefishTextView *btv,cairo_t *cr,gint w,gint height) {
+	/*gdk_draw_rectangle(GDK_DRAWABLE(event->window),GTK_WIDGET(btv)->style->fg_gc[GTK_WIDGET_STATE(btv)], TRUE,btv->margin_pixels_chars+2, w + (height / 2) - 4, 8,8);*/
+	/*gdk_cairo_set_source_color(cr, &gtk_widget_get_style(GTK_WIDGET(btv))->fg[GTK_WIDGET_STATE(btv)]);*/
+	cairo_rectangle(cr, btv->margin_pixels_chars+2, w+(height/2)-4, 8,8);
+	cairo_fill(cr);
 }
 
 static gint get_num_foldable_blocks(Tfoundstack *fstack) {
@@ -522,6 +564,11 @@ static inline void paint_margin(BluefishTextView *btv,GdkEventExpose * event, Gt
 	PangoLayout *panlay;
 	gpointer bmark;
 	gint bmarkline=-1;
+	cairo_t *cr;
+
+	cr = gdk_cairo_create(event->window);
+	cairo_set_line_width(cr, 1);
+	gdk_cairo_set_source_color(cr, &gtk_widget_get_style(GTK_WIDGET(btv))->fg[GTK_WIDGET_STATE(btv)]);
 
 	if (btv->show_line_numbers) {
 		GtkTextIter cursorit;
@@ -585,8 +632,10 @@ static inline void paint_margin(BluefishTextView *btv,GdkEventExpose * event, Gt
 				else
 					string = g_strdup_printf("%d", 1 + i);
 				pango_layout_set_markup(panlay, string, -1);
-				gtk_paint_layout(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv), FALSE, NULL,
-								 GTK_WIDGET(btv), NULL, 2, w, panlay);
+/*				gtk_paint_layout(GTK_WIDGET(btv)->style, event->window, GTK_WIDGET_STATE(btv), FALSE, NULL,
+								 GTK_WIDGET(btv), NULL, 2, w, panlay);*/
+				cairo_move_to(cr, 2, w);
+				pango_cairo_show_layout(cr, panlay);
 				g_free(string);
 			}
 			/* symbols */
@@ -595,7 +644,7 @@ static inline void paint_margin(BluefishTextView *btv,GdkEventExpose * event, Gt
 					bmarkline = bmark_margin_get_next_bookmark((Tdocument *)btv->doc, &bmark);
 				}
 				if (bmarkline == i) {
-					paint_margin_symbol(btv,event,w,height);
+					paint_margin_symbol(btv,cr,w,height);
 				}
 			}
 			/* block folding.
@@ -624,21 +673,21 @@ static inline void paint_margin(BluefishTextView *btv,GdkEventExpose * event, Gt
 					/*DBG_FOLD("search block at line %d, curline_o=%d, nextline_o=%d\n",i,curline_o,nextline_o);*/
 					if (fstackpos > nextline_o) {
 						if (num_blocks > 0) {
-							paint_margin_line(btv,event,w,height);
+							paint_margin_line(btv,cr,w,height);
 						}
 						break;
 					}
 					if (fstackpos <= nextline_o && fstackpos >= curline_o) {
 						if (fstack->pushedblock && fstack->pushedblock->foldable) {
 							if (fstack->pushedblock->folded)
-								paint_margin_collapse(btv,event,w,height);
+								paint_margin_collapse(btv,cr,w,height);
 							else
-								paint_margin_expand(btv,event,w,height);
+								paint_margin_expand(btv,cr,w,height);
 
 							num_blocks = get_num_foldable_blocks(fstack);
 							break;
 						} else if (fstack->poppedblock && fstack->poppedblock->foldable) {
-							paint_margin_blockend(btv,event,w,height);
+							paint_margin_blockend(btv,cr,w,height);
 							num_blocks = get_num_foldable_blocks(fstack);
 							break;
 						}
@@ -648,6 +697,7 @@ static inline void paint_margin(BluefishTextView *btv,GdkEventExpose * event, Gt
 			}
 		}
 	}
+	cairo_destroy(cr);
 	g_object_unref(G_OBJECT(panlay));
 }
 /* whitespace macro. Possibly include: '/n', 8206-8207, maybe others */
@@ -689,13 +739,13 @@ static inline void paint_spaces(BluefishTextView *btv, GdkEventExpose * event, G
 			gtk_text_view_buffer_to_window_coords(GTK_TEXT_VIEW(btv),GTK_TEXT_WINDOW_TEXT,rect.x,rect.y+rect.height/1.5,&x,&y);
 			if (uc == '\t' && (trailing || main_v->props.visible_ws_mode !=2)) {  
 				/* draw tab */
-				cairo_move_to(cr, x + 3, y - 3);
+				cairo_move_to(cr, x + 3.5, y - 2.5);
 				cairo_rel_line_to(cr, 0, 3);
 				cairo_rel_line_to(cr, rect.width - 6, 0);
 				cairo_rel_line_to(cr, 0, -3);
 			} else if ((uc == 160||uc==8239) && (trailing || main_v->props.visible_ws_mode !=2)) {
 				/* draw nbsp (8239= narrow-nbsp)*/
-				cairo_move_to(cr, x + 1, y);
+				cairo_move_to(cr, x + 1, y-0.5);
 				cairo_rel_line_to(cr,rect.width - 2, 0);
 			} else if (main_v->props.visible_ws_mode==0 || (main_v->props.visible_ws_mode!=1 &&trailing) ) {
 				/* draw space */
@@ -1082,7 +1132,9 @@ static gboolean bluefish_text_view_button_press_event(GtkWidget * widget, GdkEve
 			gtk_text_view_window_to_buffer_coords(GTK_TEXT_VIEW(btv), GTK_TEXT_WINDOW_TEXT, 0,event->y, &x, &y);
 			gtk_text_view_get_line_at_y(GTK_TEXT_VIEW(widget), &it, y, &x);
 
-			if (event->type == GDK_2BUTTON_PRESS) {
+			if (event->type == GDK_2BUTTON_PRESS
+					&& (event->x > (btv->margin_pixels_chars))
+					&& (event->x < (btv->margin_pixels_chars + btv->margin_pixels_symbol))) {
 				GdkRegion *region;
 				bmark_toggle(btv->doc, gtk_text_iter_get_offset(&it), NULL, NULL);
 				/* redraw margin */
@@ -1092,7 +1144,8 @@ static gboolean bluefish_text_view_button_press_event(GtkWidget * widget, GdkEve
 
 				return TRUE;
 			}
-			if (btv->show_blocks && event->x >= btv->margin_pixels_chars) { /* get the offset that equals the folding area */
+			if (btv->show_blocks
+					&& (event->x > (btv->margin_pixels_chars + btv->margin_pixels_symbol))) { /* get the offset that equals the folding area */
 				
 				gtk_text_view_get_line_at_y(GTK_TEXT_VIEW(widget), &it, y, &x);
 				DBG_FOLD("fold/unfold at offset %d (line %d)\n",gtk_text_iter_get_offset(&it),gtk_text_iter_get_line(&it));
@@ -1110,7 +1163,8 @@ static gboolean bluefish_text_view_button_press_event(GtkWidget * widget, GdkEve
 				}
 				return TRUE;
 			}
-		} else if (event->button == 3 && btv->show_blocks && event->x >= btv->margin_pixels_chars) {
+		} else if (event->button == 3
+				&& btv->show_blocks && (event->x > btv->margin_pixels_chars)) {
 			gtk_menu_popup(GTK_MENU(bftextview2_fold_menu(btv)), NULL, NULL, NULL, NULL, event->button,event->time);
 			return TRUE;
 		}
@@ -1137,50 +1191,72 @@ static gboolean bluefish_text_view_button_press_event(GtkWidget * widget, GdkEve
 	return GTK_WIDGET_CLASS(bluefish_text_view_parent_class)->button_press_event (widget, event);
 }
 
+static gchar *get_prevline_indenting(GtkTextBuffer *buffer, GtkTextIter *itend, gchar *lastchar) {
+	gchar *string;
+	gchar *indenting;
+	gint stringlen;
+
+	GtkTextIter itstart;
+	
+	itstart = *itend;
+	/* set to the beginning of the previous line */
+	gtk_text_iter_backward_line(&itstart);
+	gtk_text_iter_set_line_index(&itstart, 0);
+	string = gtk_text_buffer_get_text(buffer,&itstart,itend,TRUE);
+	if (!string)
+		return NULL;
+
+	stringlen = strlen(string);
+	if (stringlen>1) {
+		*lastchar = string[stringlen-2];
+	}
+	/* now count the indenting in this string */
+	indenting = string;
+	while (*indenting == '\t' || *indenting == ' ') {
+		indenting++;
+	}
+	/* ending search, non-whitespace found, so terminate at this position */
+	*indenting = '\0';
+	return string;	
+}
+
 static gboolean bluefish_text_view_key_release_event(GtkWidget *widget,GdkEventKey *kevent,gpointer user_data) {
 	BluefishTextView *btv=user_data;
+	gboolean prev_insert_was_auto_indent=btv->insert_was_auto_indent;
+	btv->insert_was_auto_indent = FALSE;
+	
 	/* sometimes we receive a release event for a key that was not pressed in the textview widget!
 	for example if you use the keyboard to navigate the menu, and press enter to activate an item, a 
 	key release event is received in the textview widget.... so we have to check that ! */
-	DBG_SIGNALS("bluefish_text_view_key_release_event, key_press_inserted_char=%d\n",btv->key_press_inserted_char);
-	if (btv->key_press_inserted_char && btv->auto_indent && (kevent->keyval == GDK_Return || kevent->keyval == GDK_KP_Enter) && !(kevent->state & GDK_SHIFT_MASK || kevent->state & GDK_CONTROL_MASK || kevent->state & GDK_MOD1_MASK)) {
+	if (!btv->key_press_inserted_char)
+		return FALSE;	
+	btv->key_press_inserted_char = FALSE; /* after the check we set this to FALSE */
+
+	if (!btv->auto_indent)
+		return FALSE;	
+	/*g_print("bluefish_text_view_key_release_event, working on keyval %d\n",kevent->keyval);*/
+	if ((kevent->keyval == GDK_Return || kevent->keyval == GDK_KP_Enter) && !(kevent->state & GDK_SHIFT_MASK || kevent->state & GDK_CONTROL_MASK || kevent->state & GDK_MOD1_MASK)) {
 		gchar *string;
-		GtkTextIter itstart, itend;
+		gchar lastchar='\0';
+		GtkTextIter itend;
 		GtkTextBuffer *buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(btv));
 		gtk_text_buffer_get_iter_at_mark(buffer,&itend,gtk_text_buffer_get_insert(buffer));
-		itstart = itend;
-		/* set to the beginning of the previous line */
-		gtk_text_iter_backward_line(&itstart);
-		gtk_text_iter_set_line_index(&itstart, 0);
-		string = gtk_text_buffer_get_text(buffer,&itstart,&itend,TRUE);
+		string = get_prevline_indenting(buffer, &itend, &lastchar);
+		/*g_print("bluefish_text_view_key_release_event, previoud indenting '%s'\n",string);*/
 		if (string) {
-			gchar lastchar='\0', *indenting;
-			gint stringlen;
-			
-			stringlen = strlen(string);
-			if (stringlen>1) {
-				lastchar = string[stringlen-2];
-				/*g_print("lastchar=%c\n",lastchar);*/
-			}
-			/* now count the indenting in this string */
-			indenting = string;
-			while (*indenting == '\t' || *indenting == ' ') {
-				indenting++;
-			}
-			/* ending search, non-whitespace found, so terminate at this position */
-			*indenting = '\0';
-			if (lastchar!='\0' && main_v->props.smartindent && btv->bflang && btv->bflang->smartindentchars) {
-				if(strchr(btv->bflang->smartindentchars, lastchar)!=NULL) {
-					gchar *tmp, *tmp2;
-					if (main_v->props.editor_indent_wspaces)
-						tmp2 = bf_str_repeat(" ", BFWIN(DOCUMENT(btv->doc)->bfwin)->session->editor_tab_width);
-					else 
-						tmp2 = g_strdup("	");
-					tmp = g_strconcat(string, tmp2,NULL);
-					g_free(string);
-					g_free(tmp2);
-					string = tmp;
-				}
+			/*g_print("bluefish_text_view_key_release_event, lastchar=%c, smartindentchars=%s\n",lastchar, btv->bflang->smartindentchars);*/
+			if (lastchar!='\0' && main_v->props.smartindent 
+						&& btv->bflang && btv->bflang->smartindentchars 
+						&& strchr(btv->bflang->smartindentchars, lastchar)!=NULL) {
+				gchar *tmp, *tmp2;
+				if (main_v->props.editor_indent_wspaces)
+					tmp2 = bf_str_repeat(" ", BFWIN(DOCUMENT(btv->doc)->bfwin)->session->editor_tab_width);
+				else 
+					tmp2 = g_strdup("	");
+				tmp = g_strconcat(string, tmp2,NULL);
+				g_free(string);
+				g_free(tmp2);
+				string = tmp;
 			}
 			if (string && string[0]!='\0') {
 				gboolean in_paste = DOCUMENT(btv->doc)->in_paste_operation;
@@ -1192,11 +1268,36 @@ static gboolean bluefish_text_view_key_release_event(GtkWidget *widget,GdkEventK
 				gtk_text_buffer_insert(buffer,&itend,string,-1);
 				if (!in_paste)
 					DOCUMENT(btv->doc)->in_paste_operation=FALSE;
+				btv->insert_was_auto_indent=TRUE;
 			}
 			g_free(string);
 		}
+	} else if (main_v->props.smartindent && prev_insert_was_auto_indent
+				&& btv->bflang && btv->bflang->smartoutdentchars 
+				&& strchr(btv->bflang->smartoutdentchars, kevent->keyval)!=NULL) {
+		GtkTextIter itend, itstart;
+		gunichar uc;
+		/* reduce the indenting one level back */
+		GtkTextBuffer *buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(btv));
+		gtk_text_buffer_get_iter_at_mark(buffer,&itend,gtk_text_buffer_get_insert(buffer));
+		gtk_text_iter_backward_char(&itend);
+		itstart = itend;
+		gtk_text_iter_backward_char(&itstart);
+		uc = gtk_text_iter_get_char(&itstart);
+		/*g_print("found indenting char '%c'\n",uc);*/
+		if (uc == '\t') {
+			gtk_text_buffer_delete(buffer,&itstart,&itend);
+		} else if (uc == ' ') {
+			int i=1;
+			/* if a space was the previous char, we need N spaces to unindent */
+			while (uc == ' ' && i<BFWIN(DOCUMENT(btv->doc)->bfwin)->session->editor_tab_width) {
+				gtk_text_iter_backward_char(&itstart);
+				uc = gtk_text_iter_get_char(&itstart);
+				i++;
+			}
+			gtk_text_buffer_delete(buffer,&itstart,&itend);
+		}
 	}
-	btv->key_press_inserted_char = FALSE; /* after the key release we set this to FALSE */
 	return FALSE; /* we didn't handle all of the event */
 }
 
@@ -1290,6 +1391,17 @@ void bftextview2_parse_static_colors(void) {
 	if (!(main_v->props.btv_color_str[BTV_COLOR_WHITESPACE] && gdk_color_parse(main_v->props.btv_color_str[BTV_COLOR_WHITESPACE], &st_whitespace_color))) {
 		gdk_color_parse("#ff0000",&st_whitespace_color);
 	}
+	if (main_v->props.btv_color_str[BTV_COLOR_CURSOR] != NULL && main_v->props.btv_color_str[BTV_COLOR_CURSOR][0] != '\0') {
+		gchar *tmp;
+		tmp = g_strconcat(
+				"style \"bluefish-cursor\" {"
+				"GtkTextView::cursor-color = \"",
+				main_v->props.btv_color_str[BTV_COLOR_CURSOR],
+				"\"}"
+				"class \"GtkTextView\" style \"bluefish-cursor\"", NULL);
+		gtk_rc_parse_string(tmp);
+		g_free(tmp);
+	}
 }
 
 void bluefish_text_view_set_colors(BluefishTextView * btv, gchar * const *colors) {
