@@ -1,11 +1,11 @@
 /* Bluefish HTML Editor
  * bftextview2_langmgr.c
  *
- * Copyright (C) 2008,2009 Olivier Sessink
+ * Copyright (C) 2008,2009,2010 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <libxml/xmlreader.h>
@@ -41,6 +40,7 @@ typedef struct {
 	Tcomment *line; /* while not finished */
 	Tcomment *block;/* while not finished */
 	gchar *smartindentchars;
+	gchar *smartoutdentchars;
 	Tbflang *bflang;
 	gboolean load_completion;
 	gboolean load_reference;
@@ -61,6 +61,7 @@ typedef struct {
 	GHashTable *bflang_options; /* key: a NULL terminated char **array with first value the language name,
 											second value the option name, third NULL
 											and as value a gchar * with the value of the option */
+	GtkTextTag **highlight_tags; /* text used for highlighting, so not _needscanning_ or _needspellcheck_ or _folded_ and such */
 #ifdef HAVE_LIBENCHANT
 	GtkTextTag **need_spellcheck_tags;
 	GtkTextTag **no_spellcheck_tags;
@@ -194,9 +195,20 @@ static void langmgr_load_default_styles(void) {
 	}
 }
 
+static GtkTextTag **texttag_array_from_list(GList *thelist) {
+	gint i=0;
+	GList *tmplist;
+	GtkTextTag **retval = (GtkTextTag **)g_new0(gpointer, g_list_length(thelist)+1);
+	for (tmplist = g_list_first(thelist);tmplist;tmplist=tmplist->next) {
+		retval[i] = tmplist->data;
+		i++;
+	}
+	g_list_free(thelist);
+	return retval;
+}
+
 void langmgr_reload_user_styles(void) {
-	GList *tmplist, *needlist=NULL,*noscanlist=NULL;
-	gint i;
+	GList *tmplist, *needlist=NULL,*noscanlist=NULL,*highlightlist=NULL;
 
 	if (main_v->props.textstyles == NULL) {
 		langmgr_load_default_styles();
@@ -209,6 +221,7 @@ void langmgr_reload_user_styles(void) {
 		gchar **arr = (gchar **)tmplist->data;
 		if (count_array(arr)==6) {
 			tag = langmrg_create_style(arr[0], arr[1], arr[2], arr[3], arr[4]);
+			highlightlist = g_list_prepend(highlightlist, tag);
 #ifdef HAVE_LIBENCHANT
 			if (arr[5][0]=='1')
 				needlist = g_list_prepend(needlist, tag);
@@ -217,25 +230,10 @@ void langmgr_reload_user_styles(void) {
 #endif
 		}
 	}
+	langmgr.highlight_tags = texttag_array_from_list(highlightlist);
 #ifdef HAVE_LIBENCHANT
-	langmgr.need_spellcheck_tags = (GtkTextTag **) g_new0(gpointer, g_list_length(needlist)+1);
-	i=0;
-	for (tmplist = g_list_first(needlist);tmplist;tmplist=tmplist->next) {
-		/*DBG_SPELL("tag %p in need_spellcheck_tags[%d]\n",tmplist->data,i);*/
-		langmgr.need_spellcheck_tags[i] = tmplist->data;
-		i++;
-	}
-	DBG_SPELL("have %d items in need_spellcheck_tags %p\n",i,langmgr.need_spellcheck_tags);
-	g_list_free(needlist);
-	langmgr.no_spellcheck_tags = (GtkTextTag **) g_new0(gpointer, g_list_length(noscanlist)+1);
-	i=0;
-	for (tmplist = g_list_first(noscanlist);tmplist;tmplist=tmplist->next) {
-		/*DBG_SPELL("tag %p in no_spellcheck_tags[%d]\n",tmplist->data,i);*/
-		langmgr.no_spellcheck_tags[i] = tmplist->data;
-		i++;
-	}
-	DBG_SPELL("have %d items in no_spellcheck_tags %p\n",i,langmgr.no_spellcheck_tags);
-	g_list_free(noscanlist);
+	langmgr.need_spellcheck_tags = texttag_array_from_list(needlist);
+	langmgr.no_spellcheck_tags = texttag_array_from_list(noscanlist);
 #endif
 }
 
@@ -327,6 +325,7 @@ static gboolean build_lang_finished_lcb(gpointer data)
 		bfparser->bflang->no_st = TRUE;
 	}
 	bfparser->bflang->smartindentchars = bfparser->smartindentchars;
+	bfparser->bflang->smartoutdentchars = bfparser->smartoutdentchars;
 #ifdef HAVE_LIBENCHANT
 	bfparser->bflang->default_spellcheck = bfparser->default_spellcheck;
 #endif
@@ -462,6 +461,7 @@ static guint16 process_scanning_element(xmlTextReaderPtr reader, Tbflangparsing
 	gchar *pattern=NULL, *idref=NULL, *highlight=NULL, *blockstartelement=NULL, *blockhighlight=NULL, *class=NULL, *notclass=NULL, *autocomplete_append=NULL, *autocomplete_string=NULL, *id=NULL;
 	gboolean case_insens=FALSE, is_regex=FALSE, starts_block=FALSE, ends_block=FALSE, is_empty, autocomplete=FALSE, tagclose_from_blockstack=FALSE;
 	gint ends_context=0,autocomplete_backup_cursor=0;
+	gint identifier_mode;
 	is_empty = xmlTextReaderIsEmptyElement(reader);
 
 
@@ -487,6 +487,7 @@ static guint16 process_scanning_element(xmlTextReaderPtr reader, Tbflangparsing
 			set_string_if_attribute_name(reader,aname,(xmlChar *)"autocomplete_append",&autocomplete_append);
 			set_integer_if_attribute_name(reader, aname, (xmlChar *)"autocomplete_backup_cursor", &autocomplete_backup_cursor);
 		}
+		set_integer_if_attribute_name(reader, aname, (xmlChar *)"identifier_mode", &identifier_mode);
 		xmlFree(aname);
 	}
 	tmp = lookup_user_option(bfparser->bflang->name,class);
@@ -518,7 +519,8 @@ static guint16 process_scanning_element(xmlTextReaderPtr reader, Tbflangparsing
 			}
 			matchnum = add_keyword_to_scanning_table(bfparser->st, pattern, bfparser->bflang->name, highlight?highlight:ih_highlight, blockhighlight,is_regex?is_regex:ih_is_regex,case_insens?case_insens:ih_case_insens, context, nextcontext
 					, starts_block, ends_block, blockstartelementum
-					, tagclose_from_blockstack /* the very special case for the generix xml tag close pattern */);
+					, tagclose_from_blockstack /* the very special case for the generix xml tag close pattern */
+					, identifier_mode);
 			if (autocomplete?autocomplete:ih_autocomplete) {
 				match_add_autocomp_item(bfparser->st, matchnum, autocomplete_string
 										, autocomplete_append?autocomplete_append:ih_autocomplete_append
@@ -666,13 +668,13 @@ static guint16 process_scanning_tag(xmlTextReaderPtr reader, Tbflangparsing *bfp
 				gchar *tmp2 = g_strconcat("></",tag,">",NULL);
 				matchnum = add_keyword_to_scanning_table(bfparser->st, tmp,bfparser->bflang->name
 							,highlight?highlight:ih_highlight,NULL, FALSE, case_insens, context
-							, contexttag, TRUE, FALSE, 0, 0);
+							, contexttag, TRUE, FALSE, 0, 0, 0);
 				match_add_autocomp_item(bfparser->st, matchnum, NULL, tmp2, strlen(tag)+3);
 				g_free(tmp2);
 			} else {
 				matchnum = add_keyword_to_scanning_table(bfparser->st, tmp,bfparser->bflang->name
 							,highlight?highlight:ih_highlight,NULL, FALSE, case_insens, context
-							, contexttag, TRUE, FALSE, 0, 0);
+							, contexttag, TRUE, FALSE, 0, 0, 0);
 				match_add_autocomp_item(bfparser->st, matchnum, NULL, autocomplete_append?autocomplete_append:ih_autocomplete_append, autocomplete_backup_cursor?autocomplete_backup_cursor:ih_autocomplete_backup_cursor);
 			}
 			DBG_PARSING("insert tag %s into hash table with matchnum %d\n",id?id:tmp,matchnum);
@@ -691,7 +693,7 @@ static guint16 process_scanning_tag(xmlTextReaderPtr reader, Tbflangparsing *bfp
 					while (*tmp2) {
 						guint16 attrmatch = add_keyword_to_scanning_table(bfparser->st, *tmp2,bfparser->bflang->name
 									,attribhighlight?attribhighlight:ih_attribhighlight
-									,NULL, FALSE, TRUE, contexttag, 0, FALSE, FALSE, 0, 0);
+									,NULL, FALSE, TRUE, contexttag, 0, FALSE, FALSE, 0, 0, 0);
 						match_add_autocomp_item(bfparser->st, attrmatch, NULL, attrib_autocomplete_append?attrib_autocomplete_append:ih_attrib_autocomplete_append, attrib_autocomplete_backup_cursor?attrib_autocomplete_backup_cursor:ih_attrib_autocomplete_backup_cursor);
 						match_autocomplete_reference(bfparser->st,attrmatch,contexttag);
 						tmp2++;
@@ -710,7 +712,7 @@ static guint16 process_scanning_tag(xmlTextReaderPtr reader, Tbflangparsing *bfp
 					compile_existing_match(bfparser->st,matchstring, contexttag);
 				} else {
 					/*g_print("adding new tag string %s to context %d and highlight %s\n",internal_tag_string_d,contexttag,stringhighlight);*/
-					matchstring = add_keyword_to_scanning_table(bfparser->st, "\"[^\"]*\"", bfparser->bflang->name, stringhighlight,NULL,TRUE, FALSE, contexttag, 0, FALSE, FALSE, 0, 0);
+					matchstring = add_keyword_to_scanning_table(bfparser->st, "\"[^\"]*\"", bfparser->bflang->name, stringhighlight,NULL,TRUE, FALSE, contexttag, 0, FALSE, FALSE, 0, 0, 0);
 					g_hash_table_insert(bfparser->patterns, g_strdup(internal_tag_string_d), GINT_TO_POINTER((gint)matchstring));
 				}
 				matchstring = GPOINTER_TO_INT(g_hash_table_lookup(bfparser->patterns, internal_tag_string_s));
@@ -719,19 +721,19 @@ static guint16 process_scanning_tag(xmlTextReaderPtr reader, Tbflangparsing *bfp
 					compile_existing_match(bfparser->st,matchstring, contexttag);
 				} else {
 					/*g_print("adding new tag string %s to context %d and highlight %s\n",internal_tag_string_s,contexttag,stringhighlight);*/
-					matchstring = add_keyword_to_scanning_table(bfparser->st, "'[^']*'", bfparser->bflang->name, stringhighlight,NULL,TRUE, FALSE, contexttag, 0, FALSE, FALSE, 0, 0);
+					matchstring = add_keyword_to_scanning_table(bfparser->st, "'[^']*'", bfparser->bflang->name, stringhighlight,NULL,TRUE, FALSE, contexttag, 0, FALSE, FALSE, 0, 0, 0);
 					g_hash_table_insert(bfparser->patterns, g_strdup(internal_tag_string_s), GINT_TO_POINTER((gint)matchstring));
 				}
 
 				if (!sgml_shorttag) {
 					guint16 tmpnum;
-					tmpnum = add_keyword_to_scanning_table(bfparser->st, "/>", bfparser->bflang->name, highlight?highlight:ih_highlight, NULL, FALSE, FALSE, contexttag, -1, FALSE, TRUE, -1, 0);
+					tmpnum = add_keyword_to_scanning_table(bfparser->st, "/>", bfparser->bflang->name, highlight?highlight:ih_highlight, NULL, FALSE, FALSE, contexttag, -1, FALSE, TRUE, -1, 0, 0);
 					if (bfparser->autoclose_tags)
 						match_add_autocomp_item(bfparser->st, tmpnum, NULL,NULL, 0);
 					match_autocomplete_reference(bfparser->st,tmpnum,contexttag);
 				}
 				tmp = no_close ? NULL : g_strconcat("</",tag,">",NULL);
-				starttagmatch = add_keyword_to_scanning_table(bfparser->st, ">", bfparser->bflang->name, highlight?highlight:ih_highlight, NULL, FALSE, FALSE, contexttag, -1, FALSE, FALSE, 0, 0);
+				starttagmatch = add_keyword_to_scanning_table(bfparser->st, ">", bfparser->bflang->name, highlight?highlight:ih_highlight, NULL, FALSE, FALSE, contexttag, -1, FALSE, FALSE, 0, 0, 0);
 				if (bfparser->autoclose_tags&&!no_close)
 					match_add_autocomp_item(bfparser->st, starttagmatch, NULL,tmp,tmp?strlen(tmp):0);
 				if (tmp) g_free(tmp);
@@ -782,7 +784,7 @@ static guint16 process_scanning_tag(xmlTextReaderPtr reader, Tbflangparsing *bfp
 			match_autocomplete_reference(bfparser->st,matchnum,context);
 			if (!no_close) {
 				tmp = g_strconcat("</",tag,">",NULL);
-				endtagmatch = add_keyword_to_scanning_table(bfparser->st, tmp, bfparser->bflang->name,highlight?highlight:ih_highlight,NULL, FALSE, case_insens, innercontext, (innercontext==context)?0:-2, FALSE, TRUE, matchnum, 0);
+				endtagmatch = add_keyword_to_scanning_table(bfparser->st, tmp, bfparser->bflang->name,highlight?highlight:ih_highlight,NULL, FALSE, case_insens, innercontext, (innercontext==context)?0:-2, FALSE, TRUE, matchnum, 0, 0);
 				match_add_autocomp_item(bfparser->st, endtagmatch, NULL, NULL, 0);
 				match_autocomplete_reference(bfparser->st,endtagmatch,innercontext);
 				g_hash_table_insert(bfparser->patterns, g_strdup(tmp), GINT_TO_POINTER((gint)endtagmatch));
@@ -1064,6 +1066,12 @@ static gpointer build_lang_thread(gpointer data)
 						set_string_if_attribute_name(reader,aname,(xmlChar *)"characters", &bfparser->smartindentchars);
 						xmlFree(aname);
 					}
+				} else if (xmlStrEqual(name2,(xmlChar *)"smartoutdent")) {
+					while (xmlTextReaderMoveToNextAttribute(reader)) {
+						xmlChar *aname = xmlTextReaderName(reader);
+						set_string_if_attribute_name(reader,aname,(xmlChar *)"characters", &bfparser->smartoutdentchars);
+						xmlFree(aname);
+					}
 #ifdef HAVE_LIBENCHANT
 				} else if (xmlStrEqual(name2,(xmlChar *)"default_spellcheck")) {
 					while (xmlTextReaderMoveToNextAttribute(reader)) {
@@ -1174,6 +1182,17 @@ GList *langmgr_get_languages_mimetypes(void) {
 	}
 	return retlist;
 }
+
+gboolean langmgr_in_highlight_tags(GtkTextTag *tag) {
+	gint i=0;
+	while (langmgr.highlight_tags[i]) {
+		if (langmgr.highlight_tags[i] == tag)
+			return TRUE;
+		i++;
+	}
+	return FALSE;
+}
+
 #ifdef HAVE_LIBENCHANT
 GtkTextTag **langmgr_no_spellcheck_tags(void) {
 	return langmgr.no_spellcheck_tags;
@@ -1181,7 +1200,6 @@ GtkTextTag **langmgr_no_spellcheck_tags(void) {
 GtkTextTag **langmgr_need_spellcheck_tags(void) {
 	return langmgr.need_spellcheck_tags;
 }
-
 #endif
 
 GList *langmgr_get_languages(void) {
