@@ -1,11 +1,11 @@
 /* Bluefish HTML Editor
  * bftextview2_patcompile.c
  *
- * Copyright (C) 2008,2009 Olivier Sessink
+ * Copyright (C) 2008,2009,2010 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* for the design docs see bftextview2.h */
@@ -710,7 +709,7 @@ void match_set_reference(Tscantable *st, guint16 matchnum, const gchar *referenc
 
 static guint16 new_match(Tscantable *st, const gchar *pattern, const gchar *lang, const gchar *selfhighlight, const gchar *blockhighlight, gint16 context, gint16 nextcontext
 				, gboolean starts_block, gboolean ends_block, guint16 blockstartpattern, gboolean case_insens, gboolean is_regex
-				, gboolean tagclose_from_blockstack) {
+				, gboolean tagclose_from_blockstack, guint8 identmode) {
 	guint matchnum;
 /* add the match */
 	if (context == nextcontext)
@@ -729,6 +728,9 @@ static guint16 new_match(Tscantable *st, const gchar *pattern, const gchar *lang
 	g_array_index(st->matches, Tpattern, matchnum).selfhighlight = (gchar *)selfhighlight;
 	g_array_index(st->matches, Tpattern, matchnum).blockhighlight = (gchar *)blockhighlight;
 	g_array_index(st->matches, Tpattern, matchnum).tagclose_from_blockstack = tagclose_from_blockstack;
+#ifdef IDENTSTORING
+	g_array_index(st->matches, Tpattern, matchnum).identmode = identmode;
+#endif
 	return matchnum;
 }
 
@@ -745,7 +747,7 @@ void compile_existing_match(Tscantable *st,guint16 matchnum, gint16 context) {
 guint16 add_keyword_to_scanning_table(Tscantable *st, gchar *pattern, const gchar *lang, const gchar *selfhighlight, const gchar *blockhighlight
 				, gboolean is_regex,gboolean case_insens, gint16 context, gint16 nextcontext
 				, gboolean starts_block, gboolean ends_block, guint blockstartpattern
-				, gboolean tagclose_from_blockstack)  {
+				, gboolean tagclose_from_blockstack, guint8 identmode)  {
 	guint16 matchnum;
 
 	if (!pattern || pattern[0] == '\0') {
@@ -753,7 +755,7 @@ guint16 add_keyword_to_scanning_table(Tscantable *st, gchar *pattern, const gcha
 		return 0;
 	}
 	matchnum = new_match(st, pattern, lang, selfhighlight, blockhighlight, context, nextcontext, starts_block, ends_block, blockstartpattern, case_insens, is_regex
-				, tagclose_from_blockstack);
+				, tagclose_from_blockstack, identmode);
 	DBG_PATCOMPILE("add_keyword_to_scanning_table,pattern=%s,starts_block=%d,ends_block=%d,blockstartpattern=%d, context=%d,nextcontext=%d and got matchnum %d\n",pattern, starts_block, ends_block, blockstartpattern,context,nextcontext,matchnum);
 	
 	if (is_regex) {
