@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 /*#define SPELL_PROFILING*/
 
@@ -45,6 +44,8 @@ static EnchantBroker *eb;
 static guint loops_per_timer=1000;
 
 static gboolean bftextview2_find_region2spellcheck(BluefishTextView * btv, GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end) {
+	GtkTextTag *misspelled;
+	
 	/* first find a region that needs a spellcheck */
 	gtk_text_buffer_get_start_iter(buffer, start);
 	if (!gtk_text_iter_begins_tag(start,btv->needspellcheck) ) {
@@ -64,6 +65,16 @@ static gboolean bftextview2_find_region2spellcheck(BluefishTextView * btv, GtkTe
 			return FALSE;
 		}
 	}
+	/* if the region is within a misspelled word, enlarge it to the total misspelled word
+	(this fixes the situation where you add a space in the middle of "forgotthespace" and only 
+	the space is scanned again) */
+	misspelled = gtk_text_tag_table_lookup(langmgr_get_tagtable(), "_spellerror_");
+	if (gtk_text_iter_has_tag(start, misspelled) && !gtk_text_iter_begins_tag(start,misspelled)) {
+		gtk_text_iter_backward_to_tag_toggle(start, misspelled);
+	}
+	if (gtk_text_iter_has_tag(end, misspelled) && !gtk_text_iter_ends_tag(start,misspelled)) {
+		gtk_text_iter_forward_to_tag_toggle(end, misspelled);
+	}
 	return TRUE;
 }
 
