@@ -6,7 +6,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*#define DEBUG */
@@ -141,7 +140,6 @@ static gboolean startup_in_idle(gpointer data) {
 			set_default_icon();
 			fb2config_init();			/* filebrowser2config */
 			filters_rebuild();
-			main_v->tooltips = gtk_tooltips_new();
 			main_v->bmarkdata = bookmark_data_new();
 			/* create the first window */
 			startup->firstbfwin = g_new0(Tbfwin, 1);
@@ -194,6 +192,7 @@ static gboolean startup_in_idle(gpointer data) {
 			gui_show_main(startup->firstbfwin);
 		break;
 		case 4:
+			main_v->recentm = gtk_recent_manager_get_default();
 			doc_scroll_to_cursor(BFWIN(startup->firstbfwin)->current_document);
 			modified_on_disk_check_init();
 			g_free(startup);
@@ -252,8 +251,8 @@ int main(int argc, char *argv[])
                           "xthickness = 0\n"
                           "ythickness = 0\n"
                        "}\n"
-                       "widget \"*.bluefish-small-close-button\" style \"bluefish-small-close-button-style\"");
-
+                       "widget \"*.bluefish-small-close-button\" style \"bluefish-small-close-button-style\""
+                       );
 	context = g_option_context_new(_(" [FILE(S)]"));
 #ifdef ENABLE_NLS
 	g_option_context_add_main_entries(context, options, PACKAGE);
@@ -332,6 +331,7 @@ int main(int argc, char *argv[])
 		msg_queue_start(startup->filenames, (arg_newwindow || (main_v->props.open_in_new_window && !arg_curwindow) ) );
 #else
 		if (!ipc_bf2bf_start(startup->filenames, (arg_newwindow || (main_v->props.open_in_new_window && !arg_curwindow) ) )) {
+			gdk_notify_startup_complete();
 			exit(0);
 		}
 #endif /* WITH_MSG_QUEUE */
@@ -374,11 +374,9 @@ void bluefish_exit_request()
 	g_list_free(tmplist);
 	tmplist = g_list_first(main_v->bfwinlist);
 	while (tmplist) {
-		main_window_delete_event_lcb(NULL,NULL,BFWIN(tmplist->data));
-/*		if (tmpb) {
-			file_close_all_cb(NULL, BFWIN(tmplist->data));
-		}*/
+		Tbfwin *bfwin = BFWIN(tmplist->data);
 		tmplist = g_list_next(tmplist);
+		main_window_delete_event_lcb(NULL,NULL,bfwin);
 	}
 	/* if we still have modified documents we don't do a thing,
 	   if we don't have them we can quit */
