@@ -6,7 +6,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -15,20 +15,22 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 /* indented with indent -ts4 -kr -l110   */
 
+/*#define IDENTSTORING*/
+
 /* #define HL_PROFILING */
 /* if you define DEBUG here you will get debug output from all Bluefish parts */
 /* #define DEBUG */
 
-#define DEBUG_PATHS
-
 #ifndef __BLUEFISH_H_
 #define __BLUEFISH_H_
 
+/*#define MEMORY_LEAK_DEBUG*/
+/*#define DEBUG_PATHS*/
+
 #define ENABLEPLUGINS
 
 #include "config.h"
@@ -276,6 +278,7 @@ typedef struct {
 	/* key conversion */
 	gint open_in_running_bluefish;	/* open commandline documents in already running process */
 	gint open_in_new_window;	/* open commandline files in a new window as opposed to an existing window */
+	gint register_recent_mode; /* 0=none,1=all,2=project only*/
 	GList *plugin_config;		/* array, 0=filename, 1=enabled, 2=name */
 	gchar *btv_color_str[BTV_COLOR_COUNT];	/* editor colors */
 	GList *textstyles;			/* tet styles: name,foreground,background,weight,style */
@@ -460,6 +463,11 @@ typedef struct {
 	GtkTreeModelFilter *bmarkfilter;
 	gchar *bmark_search_prefix;
 	gpointer bmarkdata;			/* a link to the global main_v->bmarkdata, OR project->bmarkdata */
+#ifdef IDENTSTORING
+	GHashTable *identifier_jump;
+	GHashTable *identifier_ac;
+#endif /* IDENTSTORING */
+
 } Tbfwin;
 
 typedef struct {
@@ -482,8 +490,8 @@ typedef struct {
 											word the user clicked */
 	gpointer bmarkdata;
 	gint num_untitled_documents;
-	GtkTooltips *tooltips;
 	gchar *securedir;			/* temporary rwx------ directory for secure file creation */
+	GtkRecentManager *recentm;
 	GSList *plugins;
 	GSList *doc_view_populate_popup_cbs;	/* plugins can register functions here that need to
 											   be called when the right-click menu in the document is populated */
