@@ -6,7 +6,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 /*#define DEBUG*/
 
@@ -787,7 +786,9 @@ static void bmark_row_activated(GtkTreeView * tree, GtkTreePath * path,
 									GtkTreeViewColumn * column, Tbfwin *bfwin) {
 	GtkTreeIter iter;
 	gtk_tree_model_get_iter(GTK_TREE_MODEL(bfwin->bmarkfilter), &iter, path);
-	bmark_activate(bfwin, get_bmark_at_iter(GTK_TREE_MODEL(bfwin->bmarkfilter), &iter), FALSE);	
+	if (gtk_tree_path_get_depth(path)==2) {
+		bmark_activate(bfwin, get_bmark_at_iter(GTK_TREE_MODEL(bfwin->bmarkfilter), &iter), FALSE);
+	}
 }
 
 /* mouse click */
@@ -984,19 +985,19 @@ GtkWidget *bmark_gui(Tbfwin * bfwin)
 
 	but = gtk_tool_button_new(gtk_image_new_from_stock(GTK_STOCK_GOTO_TOP,GTK_ICON_SIZE_MENU),"");
 	g_signal_connect(G_OBJECT(but),"clicked",G_CALLBACK(bmark_first_lcb),bfwin);
-	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(but),main_v->tooltips,_("First bookmark"),"");
+	gtk_tool_item_set_tooltip_text(GTK_TOOL_ITEM(but),_("First bookmark"));
 	gtk_toolbar_insert(GTK_TOOLBAR(hbox),but,-1);
 	but = gtk_tool_button_new(gtk_image_new_from_stock(GTK_STOCK_GO_UP,GTK_ICON_SIZE_MENU),"");
 	g_signal_connect(G_OBJECT(but),"clicked",G_CALLBACK(bmark_previous_lcb),bfwin);
-	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(but),main_v->tooltips,_("Previous bookmark"),"");
+	gtk_tool_item_set_tooltip_text(GTK_TOOL_ITEM(but),_("Previous bookmark"));
 	gtk_toolbar_insert(GTK_TOOLBAR(hbox),but,-1);
 	but = gtk_tool_button_new(gtk_image_new_from_stock(GTK_STOCK_GO_DOWN,GTK_ICON_SIZE_MENU),"");
 	g_signal_connect(G_OBJECT(but),"clicked",G_CALLBACK(bmark_next_lcb),bfwin);
-	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(but),main_v->tooltips,_("Next bookmark"),"");
+	gtk_tool_item_set_tooltip_text(GTK_TOOL_ITEM(but),_("Next bookmark"));
 	gtk_toolbar_insert(GTK_TOOLBAR(hbox),but,-1);
 	but = gtk_tool_button_new(gtk_image_new_from_stock(GTK_STOCK_GOTO_BOTTOM,GTK_ICON_SIZE_MENU),"");
 	g_signal_connect(G_OBJECT(but),"clicked",G_CALLBACK(bmark_last_lcb),bfwin);
-	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(but),main_v->tooltips,_("Last bookmark"),"");
+	gtk_tool_item_set_tooltip_text(GTK_TOOL_ITEM(but),_("Last bookmark"));
 	gtk_toolbar_insert(GTK_TOOLBAR(hbox),but,-1);
 
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
