@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* #define DEBUG */
@@ -1362,7 +1361,7 @@ GtkWidget * file_chooser_dialog(Tbfwin *bfwin, const gchar *title, GtkFileChoose
 		GtkFileFilter* ff;
 		ff = gtk_file_filter_new();
 		gtk_file_filter_set_name(ff,_("All files"));
-		gtk_file_filter_add_custom(ff, GTK_FILE_FILTER_DISPLAY_NAME, 
+		gtk_file_filter_add_custom(ff, GTK_FILE_FILTER_DISPLAY_NAME | GTK_FILE_FILTER_MIME_TYPE,
 		                           (GtkFileFilterFunc) file_chooser_custom_filter_func,
                                    new_fchooser_filter(dialog, viewbackup, NULL),g_free);
 		gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), ff);
@@ -1370,7 +1369,7 @@ GtkWidget * file_chooser_dialog(Tbfwin *bfwin, const gchar *title, GtkFileChoose
 			Tfilter *filter =tmplist->data;
 			ff = gtk_file_filter_new();
 			gtk_file_filter_set_name(ff,filter->name);
-			gtk_file_filter_add_custom(ff, GTK_FILE_FILTER_DISPLAY_NAME, 
+			gtk_file_filter_add_custom(ff, GTK_FILE_FILTER_DISPLAY_NAME | GTK_FILE_FILTER_MIME_TYPE,
 			                           (GtkFileFilterFunc) file_chooser_custom_filter_func,
                                        new_fchooser_filter(dialog, viewbackup, filter),g_free);
 			gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), ff);
