@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*#define DEBUG*/
@@ -800,6 +799,9 @@ void main_window_destroy_lcb(GtkWidget *widget,Tbfwin *bfwin) {
 	DEBUG_MSG("main_window_destroy_lcb, will destroy the window now\n");
 	gtk_widget_destroy(bfwin->main_window);
 	DEBUG_MSG("main_window_destroy_lcb, going to free bfwin %p\n",bfwin);
+#ifdef IDENTSTORING
+	bftextview2_identifier_hash_destroy(bfwin);
+#endif
 	g_free(bfwin);
 	
 	if (NULL == main_v->bfwinlist) {
@@ -974,6 +976,11 @@ static void gui_create_gotoline_frame(Tbfwin *bfwin) {
 void gui_create_main(Tbfwin *bfwin) {
 	GtkWidget *vbox;
 	DEBUG_MSG("gui_create_main, bfwin=%p, main_window_w=%d\n",bfwin,main_v->globses.main_window_w);
+
+#ifdef IDENTSTORING
+	bftextview2_identifier_hash_init(bfwin);
+#endif /* IDENTSTORING */
+
 	bfwin->main_window = window_full2(_("New Bluefish Window"), GTK_WIN_POS_CENTER, 0, G_CALLBACK(main_window_destroy_lcb), bfwin, FALSE, NULL);
 	gtk_window_set_role(GTK_WINDOW(bfwin->main_window), "bluefish");
 	gtk_widget_realize(bfwin->main_window);
@@ -1281,6 +1288,8 @@ void gui_toggle_hidewidget_cb(Tbfwin *bfwin,guint action,GtkWidget *widget) {
 
 Tbfwin *gui_new_window(Tproject *project) {
 	Tbfwin *bfwin = g_new0(Tbfwin,1);
+	g_print("gui_new_window, start bfwin %p\n",bfwin);
+
 	if (project) {
 		bfwin->project = project;
 		bfwin->session = project->session;
