@@ -10,7 +10,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -19,8 +19,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include <gtk/gtk.h>
 #include <stdlib.h>			/* atoi */
@@ -221,7 +220,11 @@ static GtkItemFactoryEntry menu_items[] = {
 	{N_("/File/Open _Recent"), NULL, NULL, 0, "<Branch>"},
 	{"/File/Open Recent/tearoff1", NULL, NULL, 0, "<Tearoff>"},
 	{N_("/File/Open Ad_vanced..."), "<shift><control>O", menu_file_operations_cb, 3, "<Item>"},
+#ifndef WIN32
+#ifndef MAC_INTEGRATION
 	{N_("/File/Open _URL..."), NULL, menu_file_operations_cb, 25, "<Item>"},
+#endif /*ifndef MAC_INTEGRATION*/
+#endif /*ifndef WIN32*/
 	{N_("/File/Open _From Selection"), NULL, menu_file_operations_cb, 26, "<Item>"},
 	{N_("/File/_Insert..."), NULL, file_insert_menucb, 1, "<Item>"},
 	{"/File/sep1", NULL, NULL, 0, "<Separator>"},
@@ -334,6 +337,7 @@ static GtkItemFactoryEntry menu_items[] = {
 	{"/Go/sep3", NULL, NULL, 0, "<Separator>"},
 	{N_("/Go/Goto _Line"), "<control>l", gui_gotoline_frame_show, 1, "<StockItem>", GTK_STOCK_JUMP_TO},
 	{N_("/Go/Goto line number in _selection"), NULL, go_to_line_from_selection_cb, 1, "<Item>"},
+	{N_("/Go/Jump to reference"), "<control>j", doc_menu_lcb, 16, "<Item>"},
 	{N_("/_Project"), NULL, NULL, 0, "<Branch>"},
 	{"/Project/tearoff1", NULL, NULL, 0, "<Tearoff>"},
 	{N_("/Project/_New Project"), NULL, project_menu_cb, 6, "<Item>"},
@@ -745,12 +749,24 @@ void recent_menu_init_project(Tbfwin *bfwin) {
 	bfwin->menu_recent_files = recent_menu_from_list(bfwin, bfwin->session->recent_files, FALSE);
 }
 
+static void register_recent(gchar *curi, gboolean is_project) {
+	if (main_v->props.register_recent_mode==0)
+		return;
+	if(is_project) {
+		gtk_recent_manager_add_item(main_v->recentm, curi);
+		return;
+	}
+	if (main_v->props.register_recent_mode==1) {
+		gtk_recent_manager_add_item(main_v->recentm, curi);
+	}
+}
 /* Add_to_recent_list
  * This should be called when a new file is opened, i.e. from
  * file_open_cb, it adds a new entry which also appears in the
  * menu bar, and (if nessecary) deletes the last entry */
 void add_to_recent_list(Tbfwin *bfwin, GFile *file, gint closed_file, gboolean is_project) {
 	gchar *filename = g_file_get_uri(file);
+	register_recent(filename,is_project);
 	if (closed_file) {
 		GList *tmplist = g_list_first(main_v->bfwinlist);
 		while (tmplist) {
