@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 /*#define DEBUG*/
 
@@ -159,11 +158,11 @@ static gpointer snippets_build_pageSnr(Tsnipwiz *snwiz, GtkWidget *dialog_action
 	gtk_table_attach(GTK_TABLE(p->table), p->matchtype, 1, 2, 4, 5, GTK_EXPAND|GTK_FILL,GTK_SHRINK, 0, 0);
 	
 	p->casesens = gtk_check_button_new_with_mnemonic(_("Case sensitive _matching"));
-	gtk_tooltips_set_tip(main_v->tooltips,p->casesens,_("Only match if case (upper/lower) is identical."),NULL);
+	gtk_widget_set_tooltip_text(p->casesens,_("Only match if case (upper/lower) is identical."));
 	gtk_table_attach(GTK_TABLE(p->table), p->casesens, 0, 2, 5, 6, GTK_EXPAND|GTK_FILL,GTK_SHRINK, 0, 0);
 	
 	p->escapechars = gtk_check_button_new_with_mnemonic(_("_Use escape chars"));
-	gtk_tooltips_set_tip(main_v->tooltips,p->escapechars,_("Unescape backslash escaped characters such as \\n, \\t etc."),NULL);
+	gtk_widget_set_tooltip_text(p->escapechars,_("Unescape backslash escaped characters such as \\n, \\t etc."));
 	gtk_table_attach(GTK_TABLE(p->table), p->escapechars, 0, 2, 6, 7, GTK_EXPAND|GTK_FILL,GTK_SHRINK, 0, 0);
 	
 	for (i = 0; i <  6; i++) {
