@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*#define DEBUG*/
@@ -50,6 +49,7 @@ enum {
 	editor_font_string,           /* editor font */
 	editor_smart_cursor,
 	editor_indent_wspaces,
+	editor_tab_indent_sel,
 	tab_font_string,              /* notebook tabs font */
 	/*tab_color_normal,*/           /* notebook tabs text color normal.  This is just NULL! */
 	tab_color_modified,           /* tab text color when doc is modified and unsaved*/
@@ -99,6 +99,7 @@ enum {
 	open_in_running_bluefish,     /* open commandline documents in already running session*/
 	open_in_new_window, 
 #endif /* ifndef WIN32 */
+	register_recent_mode,
 	load_reference,
 	show_autocomp_reference,
 	show_tooltip_reference,
@@ -109,6 +110,7 @@ enum {
 	editor_bg,
 	cline_bg,
 	visible_ws,
+	cursor_color,
 	/* now the entries in globses */
 	left_panel_width,
 	main_window_h,
@@ -1295,11 +1297,13 @@ static void preferences_apply(Tprefdialog *pd) {
 	string_apply(&main_v->props.editor_font_string, pd->prefs[editor_font_string]);
 	integer_apply(&main_v->props.editor_smart_cursor, pd->prefs[editor_smart_cursor], TRUE);
 	integer_apply(&main_v->props.editor_indent_wspaces, pd->prefs[editor_indent_wspaces], TRUE);
+	integer_apply(&main_v->props.editor_tab_indent_sel, pd->prefs[editor_tab_indent_sel], TRUE);
 	integer_apply(&main_v->props.smartindent, pd->prefs[smartindent], TRUE);
 	string_apply(&main_v->props.btv_color_str[BTV_COLOR_ED_FG], pd->prefs[editor_fg]);
 	string_apply(&main_v->props.btv_color_str[BTV_COLOR_ED_BG], pd->prefs[editor_bg]);
 	string_apply(&main_v->props.btv_color_str[BTV_COLOR_CURRENT_LINE], pd->prefs[cline_bg]);
 	string_apply(&main_v->props.btv_color_str[BTV_COLOR_WHITESPACE], pd->prefs[visible_ws]);
+	string_apply(&main_v->props.btv_color_str[BTV_COLOR_CURSOR], pd->prefs[cursor_color]);
 	integer_apply(&main_v->props.right_margin_pos, pd->prefs[right_margin_pos], FALSE);
 	main_v->props.visible_ws_mode = gtk_option_menu_get_history(GTK_OPTION_MENU(pd->prefs[visible_ws_mode]));
 	/*integer_apply(&main_v->props.defaulthighlight, pd->prefs[defaulthighlight], TRUE);*/
@@ -1338,6 +1342,7 @@ static void preferences_apply(Tprefdialog *pd) {
 	integer_apply(&main_v->props.open_in_running_bluefish, pd->prefs[open_in_running_bluefish], TRUE);
 	integer_apply(&main_v->props.open_in_new_window, pd->prefs[open_in_new_window], TRUE);
 #endif /* ifndef WIN32 */
+	main_v->props.register_recent_mode = gtk_option_menu_get_history(GTK_OPTION_MENU(pd->prefs[register_recent_mode]));
 	main_v->props.modified_check_type = gtk_option_menu_get_history(GTK_OPTION_MENU(pd->prefs[modified_check_type]));
 	integer_apply(&main_v->props.do_periodic_check, pd->prefs[do_periodic_check], TRUE);
 	integer_apply(&main_v->props.max_recent_files, pd->prefs[max_recent_files], FALSE);
@@ -1551,12 +1556,15 @@ static void preferences_dialog() {
 	pd->prefs[editor_font_string] = prefs_string(_("Font"), main_v->props.editor_font_string, vbox2, pd, string_font);
 	pd->prefs[editor_fg] = prefs_string(_("Foreground color"), main_v->props.btv_color_str[BTV_COLOR_ED_FG], vbox2, pd, string_color);
 	pd->prefs[editor_bg] = prefs_string(_("Background color"), main_v->props.btv_color_str[BTV_COLOR_ED_BG], vbox2, pd, string_color);
+	pd->prefs[cursor_color] = prefs_string(_("Cursor color"), main_v->props.btv_color_str[BTV_COLOR_CURSOR], vbox2, pd, string_color);
 	pd->prefs[cline_bg] = prefs_string(_("Current line color"), main_v->props.btv_color_str[BTV_COLOR_CURRENT_LINE], vbox2, pd, string_color);
 	pd->prefs[visible_ws] = prefs_string(_("Visible whitespace color"), main_v->props.btv_color_str[BTV_COLOR_WHITESPACE], vbox2, pd, string_color);
 	pd->prefs[right_margin_pos] = prefs_integer(_("Right margin position"), main_v->props.right_margin_pos, vbox2, 1, 1000);
 	pd->prefs[visible_ws_mode] = boxed_optionmenu_with_value(_("Show whitespace"), main_v->props.visible_ws_mode, vbox2, visible_ws_modes);
 	pd->prefs[editor_smart_cursor] = boxed_checkbut_with_value(_("Smart Home/End cursor positioning"), main_v->props.editor_smart_cursor, vbox2);
 	pd->prefs[editor_indent_wspaces] = boxed_checkbut_with_value(_("Use spaces to indent, not tabs"), main_v->props.editor_indent_wspaces, vbox2);
+	pd->prefs[editor_tab_indent_sel] = boxed_checkbut_with_value(_("Tab key indents selection"), main_v->props.editor_tab_indent_sel, vbox2);
+	
 	pd->prefs[smartindent] = boxed_checkbut_with_value(_("Smart auto indenting"), main_v->props.smartindent, vbox2);
 
 	{
@@ -1650,7 +1658,10 @@ static void preferences_dialog() {
 	pd->prefs[modified_check_type] = boxed_optionmenu_with_value(_("File properties to check on disk for modifications"), main_v->props.modified_check_type, vbox2, modified_check_types);
 	pd->prefs[do_periodic_check] = boxed_checkbut_with_value(_("Periodically check if file is modified on disk"), main_v->props.do_periodic_check, vbox2);
 	pd->prefs[max_recent_files] = prefs_integer(_("Number of files in 'Open recent' menu"), main_v->props.max_recent_files, vbox2, 3, 100);
-
+	{
+		gchar *registerrecentmodes[] = {N_("Never"), N_("All files"), N_("Only project files"), NULL};
+		pd->prefs[register_recent_mode] = boxed_optionmenu_with_value(_("Register recent files with your desktop"), main_v->props.register_recent_mode, vbox2, registerrecentmodes);
+	}
 
 	vbox1 = gtk_vbox_new(FALSE, 5);
 	gtk_tree_store_append(pd->nstore, &auxit, &iter);
