@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #define CURCONFIG "rcfile-2.0"
@@ -430,12 +429,14 @@ static GHashTable *props_init_main(GHashTable * config_rc)
 	init_prop_integer(&config_rc, &main_v->props.link_management, "link_management:", 1, TRUE);
 	init_prop_integer (&config_rc, &main_v->props.open_in_running_bluefish,"open_in_running_bluefish:",1, TRUE);
 	init_prop_integer (&config_rc, &main_v->props.open_in_new_window,"open_in_new_window:",1, TRUE);
+	init_prop_integer (&config_rc, &main_v->props.register_recent_mode,"register_recent_mode:",2, TRUE);
 	init_prop_arraylist (&config_rc, &main_v->props.plugin_config, "plugin_config:", 3, TRUE);
 	init_prop_string    (&config_rc, &main_v->props.btv_color_str[BTV_COLOR_ED_FG],"editor_fg:","#000000");
 	init_prop_string    (&config_rc, &main_v->props.btv_color_str[BTV_COLOR_ED_BG],"editor_bg:","#FFFFFF");
 	init_prop_string    (&config_rc, &main_v->props.btv_color_str[BTV_COLOR_CURRENT_LINE],"cline_bg:","#E0E0E0");
 	init_prop_string    (&config_rc, &main_v->props.btv_color_str[BTV_COLOR_WHITESPACE],"visible_ws:","#FF0000");
 	init_prop_string    (&config_rc, &main_v->props.btv_color_str[BTV_COLOR_RIGHT_MARGIN],"right_margin:","#990000");
+	init_prop_string    (&config_rc, &main_v->props.btv_color_str[BTV_COLOR_CURSOR],"cursor_color:","");
 	init_prop_arraylist (&config_rc, &main_v->props.textstyles, "textstyles3:", 6, TRUE);
 	init_prop_integer   (&config_rc, &main_v->props.block_folding_mode, "block_folding_mode:", 1, TRUE);
 	init_prop_arraylist (&config_rc, &main_v->props.highlight_styles, "highlight_styles:", 3, TRUE);
@@ -613,8 +614,8 @@ void rcfile_parse_main(void)  {
 	}
 #endif /* ifdef WIN32 elif PLATFORM_DARWIN */
 	if (main_v->props.templates==NULL) {
-		main_v->props.templates = g_list_append(main_v->props.templates, array_from_arglist(_("C Header"), PKGDATADIR"/templates/C_Header", NULL));
-		main_v->props.templates = g_list_append(main_v->props.templates, array_from_arglist(_("C Header GPL"), PKGDATADIR"/templates/C_Header_GPL", NULL));
+		main_v->props.templates = g_list_append(main_v->props.templates, array_from_arglist(_("C Header"), PKGDATADIR"/templates/C_header", NULL));
+		main_v->props.templates = g_list_append(main_v->props.templates, array_from_arglist(_("C Header GPL"), PKGDATADIR"/templates/C_header_GPL", NULL));
 		main_v->props.templates = g_list_append(main_v->props.templates, array_from_arglist(_("XHTML 1.0"), PKGDATADIR"/templates/XHTML_1.0", NULL));
 		main_v->props.templates = g_list_append(main_v->props.templates, array_from_arglist(_("HTML 5"), PKGDATADIR"/templates/HTML_5", NULL));
 		main_v->props.templates = g_list_append(main_v->props.templates, array_from_arglist(_("PHP"), PKGDATADIR"/templates/PHP", NULL));
@@ -731,7 +732,7 @@ static GHashTable *return_session_configlist(GHashTable *configlist, Tsessionvar
 	init_prop_integer   (&configlist, &session->filebrowser_show_hidden_files, "fb_show_hidden_f:", 0, FALSE);
 	init_prop_integer   (&configlist, &session->filebrowser_show_backup_files, "fb_show_backup_f:", 0, FALSE);
 	init_prop_integer   (&configlist, &session->filebrowser_focus_follow, "fb_focus_follow:", 1, FALSE);
-	init_prop_integer   (&configlist, &session->filebrowser_viewmode, "fb_viewmode:", 2, FALSE);
+	init_prop_integer   (&configlist, &session->filebrowser_viewmode, "fb_viewmode:", 1, FALSE);
 	init_prop_integer   (&configlist, &session->bookmarks_filename_mode,"bookmarks_filename_mode:",1, FALSE);
 	init_prop_integer   (&configlist, &session->bookmarks_show_mode,"bookmarks_show_mode:",0, FALSE);
 	init_prop_integer   (&configlist, &session->bmarksearchmode,"bmarksearchmode:",0, FALSE);
